summaryrefslogtreecommitdiffstats
path: root/parts/filecreate/filecreate_part.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'parts/filecreate/filecreate_part.cpp')
-rw-r--r--parts/filecreate/filecreate_part.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/parts/filecreate/filecreate_part.cpp b/parts/filecreate/filecreate_part.cpp
index e7ad379e..75523c5d 100644
--- a/parts/filecreate/filecreate_part.cpp
+++ b/parts/filecreate/filecreate_part.cpp
@@ -61,9 +61,9 @@ K_EXPORT_COMPONENT_FACTORY( libkdevfilecreate, FileCreateFactory( data ) )
using namespace FileCreate;
-FileCreatePart::FileCreatePart(TQObject *tqparent, const char *name, const TQStringList & )
-// : KDevCreateFile(&data, tqparent, name ? name : "FileCreatePart"), m_selectedWidget(-1), m_useSideTab(true), m_subPopups(0)
- : KDevCreateFile(&data, tqparent, name ? name : "FileCreatePart"), m_subPopups(0)
+FileCreatePart::FileCreatePart(TQObject *parent, const char *name, const TQStringList & )
+// : KDevCreateFile(&data, parent, name ? name : "FileCreatePart"), m_selectedWidget(-1), m_useSideTab(true), m_subPopups(0)
+ : KDevCreateFile(&data, parent, name ? name : "FileCreatePart"), m_subPopups(0)
{
setInstance(FileCreateFactory::instance());
setXMLFile("kdevpart_filecreate.rc");
@@ -483,7 +483,7 @@ void FileCreatePart::slotInitialize( )
}
} else {
// if an extension + subtype have been specified, enable
// the subtype and the extension (the 'tqparent')
FileType * filetype = getType(ext);
FileType * subtype = getType(ext,subtyperef);
if (filetype && subtype) {
@@ -483,7 +483,7 @@ void FileCreatePart::slotInitialize( )
} else {
// if an extension + subtype have been specified, enable
- // the subtype and the extension (the 'tqparent')
+ // the subtype and the extension (the 'parent')
FileType * filetype = getType(ext);
FileType * subtype = getType(ext,subtyperef);